Форум spinkat.ru • Личный раздел • Регистрация

ФорумВсе о рыбалке и снастях
Расширенный поиск

Язык:

## Форум spinkat.ru - Регистрация

Заходя на конференцию «Форум spinkat.ru» (в дальнейшем «мы», «наш», «Форум spinkat.ru», «http://www.spinkat.ru/forum»), вы подтверждаете своё согласие со следующими условиями. Если вы не согласны с ними, пожалуйста, не заходите и не пользуйтесь форумами «Форум spinkat.ru». Мы оставляем за собой право изменять эти правила в любое время и сделаем всё возможное, чтобы уведомить вас об этом, однако с вашей стороны было бы разумным регулярно просматривать этот текст на предмет изменений, так как использование конференции «Форум spinkat.ru» после обновления/исправления условий означает ваше согласие с ними.
Наши форумы работают под управлением программного обеспечения для создания конференций phpBB (в дальнейшем «они», «программное обеспечение phpBB», «www.phpbb.com», «phpBB Group», «phpBB Teams»), выпущенного по лицензии «General Public License» (в дальнейшем «GPL»). Скачать его можно по адресу www.phpbb.com. Ограничения лицензии GPL для программного обеспечения phpBB строго связаны с организацией и поддержкой интернет-конференций, и phpBB Group не несёт ответственности за то, что администрация конференций определяет в качестве допустимого содержания и/или поведения в них. За дополнительной информацией о phpBB обращайтесь по адресу https://www.phpbb.com/.
Вы соглашаетесь не размещать оскорбительных, угрожающих, клеветнических сообщений, порнографических сообщений, призывов к национальной розни и прочих сообщений, которые могут нарушить законы вашей страны, страны, которая предоставляет услуги хостинга для форумов «Форум spinkat.ru» или международное право. Попытки размещения таких сообщений могут привести к вашему немедленному отключению от конференции, при этом ваш провайдер будет поставлен в известность, если мы сочтём это нужным. IP-адреса всех сообщений сохраняются для возможности проведения такой политики. Вы соглашаетесь с тем, что администраторы форумов «Форум spinkat.ru» имеют право удалить, отредактировать, перенести или закрыть любую тему в любое время по своему усмотрению. Как пользователь вы согласны с тем, что введённая вами информация будет храниться в базе данных. Хотя эта информация не будет открыта третьим лицам без вашего разрешения, ни администрация конференции «Форум spinkat.ru», ни phpBB Group не может быть ответственна за действия хакеров, которые могут привести к несанкционированному доступу к ней.